+++
title = "Post heading with crazy characters"
date = 2017-07-12T13:46:33-04:00
draft = false
+++

## Releasing version 1.1 {#releasing-version-1-dot-1}


## Foo ( Bar ) Baz {#foo--bar--baz}


## (Foo)Bar.Baz&Zoo {#foo--bar-dot-baz-and-zoo}

-   `.` → `dot`
-   `&` → `and`


## C++ {#c-plus-plus}

-   `+` → `plus`


## Hey! I have a link [here](https://example.org) (Awesome!) {#hey-i-have-a-link-here--awesome}


## Este título es en español {#este-título-es-en-español}


## Non-English titles {#non-english-titles}


### ÂÊÎÔÛ {#âêîôû}


### ÁÉÍÓÚÝ {#áéíóúý}


### ÀÈÌÒÙ {#àèìòù}


### ÄËÏÖÜ {#äëïöü}


### ÃÐÑÕÞ {#ãðñõþ}


### Ç {#ç}


## Headings with HTML {#headings-with-html}


### Checklist <code>[1/3]</code> {#checklist}

Above title would render to `Checklist <code>[1/3]</code>` in
Markdown.


#### <span class="org-todo done DONE">DONE</span> Item 1 {#item-1}

Above would render to `<span class="todo DONE_">DONE </span> Item 1`
in Markdown.


#### <span class="org-todo todo TODO">TODO</span> Item 2 {#item-2}

Above would render to `<span class="todo TODO_">TODO </span> Item 2`
in Markdown.


#### <span class="org-todo todo TODO">TODO</span> Item 3 {#item-3}

Above would render to `<span class="todo TODO_">TODO </span> Item 3`
in Markdown.


### Version 0.1 <span class="timestamp-wrapper"><span class="timestamp">&lt;2017-10-11 Wed&gt;</span></span> {#version-0-dot-1}

Above title would render to `Version 0.1 <span
class="timestamp-wrapper"><span class="timestamp">&lt;2017-10-11
Wed&gt;</span></span>` in Markdown.
